function strainenergy(ip1,diameter,laststrainpt, ...
orderpoly,loadat1percent)
% COMMAND: strainenergy <i/p file> <diameter> ...
%        <laststrainpt> <orderpolyn> <loadat1percent>
% OUTPUT: 
%   FL THK [m] 
%   STRSI  [N/m2] 
%   STRAINI
%   STFFNSS[N/m2]
%   MXSTR  [N/m2] 
%   STRAINMX 
%   UINFLX [N/m2]
%   UMXPT  [N/m2]
%   UPOUT  [N/m2]
%   USURF  [N/m2]
%
% Note:
% CALCULATES STIFFNESS, STRENGTH, FAILURE ENERGIES, u1,u2,u3;
% OUTPUTS THE 'SURFACE TENSIONAL STRESS' (ss)
% diameter = (meter) of tendons
% lastrainpt:
%          REFERS TO LAST PT AT THE END OF THE DIP IN
%          STRESS; HERE, THE REGION FROM POST PEAK STRESS
%          COVERING THE DIP IN STRESS UNTIL THE LAST PT
%          IS REFERED TO AS THE PULLOUT REGION.
%                          
% loadat1percent = Yes or No for analysing the s-e curve by 
% using load at 1 percent of maximum load.
%
% VERSION 3- attempts to refine the est of the pull-out energy
% VERSION 4- Calculates the total energy up to the last data point
%          - Calculates the SED of the ~constant stress region
%          - NOTE: SED= Strain energy density

% CONSTANTS
GMTOKG=0.001;    % grammes to kilogrammes
gc=9.81;         % m/s/s

[f1id,message]=fopen(ip1,'r');

if (f1id == -1 )
  disp(message)
  fclose(f1id);
end

thickness=str2num(diameter);
radius=str2num(diameter)/2;
ez1=str2num(laststrainpt);
ord=str2num(orderpoly);

sxn=pi*radius*radius; % CROSS SECTIONAL AREA

% READING REDUNDANT LINES
for j=1:3
  line=fgetl(f1id);
end

% READING DATA
i=1;
while feof(f1id)==0
  line=fgetl(f1id);

  input1=sscanf(line,'%f');

  mm(i)=input1(4); % displacement in mm
  gm(i)=input1(5); % loading force in grams

  i=i+1;
end
nmax=i-1; %NMAX: MAX NO. OF POINTS

% SHIFT THE CURVE TO START AT GRAM=0
gm0=gm(1);
if gm0<0
  for i=1:nmax
    gm(i)=gm(i)+abs(gm0);
    %sprintf('%f, %f',srz1(i),tau(i))
  end
elseif gm0>0
  for i=1:nmax
    gm(i)=gm(i)-abs(gm0);
    end
end

% LOCATING THE STARTING POINT FOR mm = 0
% FIRST FIND THE MAXIMUM value of gm
gmx=0.;
for i=1:nmax
  if gmx < gm(i)
    gmx=gm(i);
  end
end

if loadat1percent=='Y'
  gm1=0.01*(gmx-gm(1)); % THE VALUE OF THE LOAD AT 1% OF MAXIMUM LOAD
elseif loadat1percent=='N'
  gm1=gm(1);
end

i=1;
while gm1>gm(i) % LOCATING THE INDEX AT 1% MX LOAD
  i=i+1;    
end
i=i-1;
len=mm(i); % GRIP TO GRIP LENGTH    
starti=i;  % INDEX FOR STARTING NEW ARRAY
nmax2=nmax-i+1; % NMAX2:NEW MAX DATA AFTER SHIFTIN STRSS (DATA)
% NOTE THE VALUE OF i IS USED FOR NEXT FOR-LOOP.
for j=1:nmax2
  gm2(j)=gm(i)-gm(starti);
  mm2(j)=mm(i)-len;

  sz(j)=gm2(j)*GMTOKG*gc/sxn; % STRESS
  ez(j)=mm2(j)/len;           % STRAIN
  i=i+1; % NOTE: i BEGAN FROM THE END OF THE PREVIOUS for-loop
end

X=[0 ez(nmax2)];         % USE THE SET OF X,Y 
Y=[sz(nmax2) sz(nmax2)]; % FOR DRAWING HORIZONTAL LINE

sz_all=sz;ez_all=ez;%sz_all,ez_all:ALL POINTS,AFTER SHIFTNG

% DETERMINE ARRAY UPTO LAST STRAIN PT IN PULLOUT REGION
j=1;
while ez(j)<ez1 %ez1: USER DEFINED LAST STRAIN PT
  j=j+1;
end
%DETERMIING THE PULLOUT REGION
nmaxm=j-1; %NMAXM: N DATA UPTO LAST PT IN PULLOUT REGION (DATA)
j=1;
while ez(j)<=ez(nmaxm)
    j=j+1;
end
h=j;

j=1;
while ez(j)<=ez(h)
    j=j+1;
end
k=j;

ss=sz(nmax2); %SURFACE TENSIONAL STRESS
ez_h=ez(h); ez_k=ez(k);
sz_h=sz(h)-ss; sz_k=sz(k)-ss;
%X0=[ez(nmaxm) ez(h) ez(k)];      %FOR DRAWING TWO LINES
%Y0=[sz(nmaxm) sz(h)-ss sz(k)-ss] %FOR DRAWING TWO LINES

% DETERMINING MAX STRESS & STRAIN AT MAX STRESS
mxsz=0.;  % MAX STRESS           (DATA)
ezmxs=0.; % STRAIN AT MAX STRESS (DATA)
for j=1:nmaxm
  if mxsz<=sz(j)
    mxsz=sz(j); %MAX STRESS         (DATA)
    ezmxs=ez(j);%STRAIN AT MX STRSS (DATA)
    nmax3=j;    %NMAX3: N DATA UP TO MAX STRESS (DATA)
  end
end

% DETERMINE THE STRESS-STRAIN ARRAY UP TO MAX STRESS
for i=1:nmax3
  sz0(i)=sz(i); % EXPT DATA OF SZ
  ez0(i)=ez(i); % EXPT DATA OF EZ
end
p=polyfit(ez0,sz0,ord); % COEFFICIENTS OF POLYNOMIAL 5th ORDER 
ndiv=100;  %ndiv: N DATA FROM ORIGIN TO MAX STRESS (POLYN)
ezx(1)=ez0(1);ezx(ndiv)=ez0(nmax3);
rangex=ezx(ndiv)-ezx(1);
for i=2:ndiv-1
  ezx(i)=ezx(1)+i*rangex/ndiv;
end
psz=polyval(p,ezx);  %PREDICTED VALUES OF SZ USNG THE FITTED POLYNML
der=polyder(p);
dsz=polyval(der,ezx);%DERIVATVE OF psz v ezx;GET DATA ARRAY OF dsz v ezx

% DETERMINE STIFFNESS OF MATERIALS AT PT OF INFLEXION OF POLYNML CURVE
i=1;
while dsz(i) < 0 % IGNORING NEGATIVE GRADIENT AT INITIAL PART OF PLOT
    i=i+1;
end
stffnss=0.;      % SET STIFFNESS=0 BEFORE SEARCHING FOR MAX GRAD          
j=i;
while stffnss <= dsz(j) %SEARCHING FOR THE MAXIMUM GRADIENT, i.e. MAX(dsz)
  stffnss=dsz(j);
  j=j+1;
end
ninflx=j-1;   %NINFLX: NO. OF PTs UP TO PI (POLYN)
ezs=ezx(j-1); %ezs:COORDINATE AT MAX GRAD  (POLYN)
szs=psz(j-1); %szs:COORDINATE AT MAX GRAD  (POLYN)

% DETERMINE (SED) AREA FROM ORIGIN TO PT OF INFLXN (POLYN)
ui=0.;
for i=1:ninflx-1
  h=ezx(i+1)-ezx(i);
  ui=ui+0.5*(psz(i)+psz(i+1))*h;
end

% DETERMINE (SED) AREA FROM PT INFLXN TO MAX STRESS (POLYN)
u1=0.;
for j=ninflx:ndiv-1 %SED FROM ORIGIN TO MAX STRESS (POLYN)
  h=ezx(j+1)-ezx(j);
  u1=u1+0.5*(psz(j)+psz(j+1))*h;
end
%u1: SED FROM PT INFLXN TO MAX STRESS

% DETERMINE (SED) AREA FROM MAXSTRSS TO 
% LAST USER-DEFINED STRAIN PT OF PULL-OUT
% BUT... FIRST FIND THE TOTAL SED
u0=0.;
for j=1:nmax2-1
  h=ez(j+1)-ez(j);
  u0=u0+0.5*(sz(j)+sz(j+1))*h;
end

%DETERMINE SED FROM MAX PT TO LAST PT
u0_2=u0-u1-ui;
u3=0.; %SED FROM LAST PULLOUT PT TO LAST DATA PT
for j=nmaxm:nmax2-1
  h=ez(j+1)-ez(j);
  u3=u3+0.5*(sz(j)+sz(j+1))*h;
end
u2=u0_2-u3; %SED FROM MAX PT TO LAST PULLOUT PT

for i=1:nmaxm
  tmp2(i)=ez(i);
  tmp1(i)=sz(i);
end
for i=1:nmax2
  sz(i)=0;
  ez(i)=0;
end
for i=1:nmaxm
  sz(i)=tmp1(i);
  ez(i)=tmp2(i);
end

%sprintf('FL THK[m] MXSTR[N/m2] STRAINMX STFFNSS UMXPT UPOUT SSURF')
sprintf('%s %.6f %.1f %.3f %.1f %.1f %.3f %.1f %.1f %.1f %.1f %.1f'...
    ,ip1,thickness,szs,ezs,stffnss,mxsz,ezmxs,ui,u1,u2,u3,ss)
%ip1: THE DATA FILE IN CONSIDERATION
%thickness: DIAMETER OF SAMPLE
%szs: STRESS AT PT INFLXN
%ezs: STRAIN AT PT INFLXN
%stffnss:STIFFNESS AT PT INFLXN
%mxsz: MAXIMUM STRESS
%ezmxs: STRAIN AT MAXIMUM STRESS
%ui: SED ORIGIN TO PT INFLXN
%u1: SED PT INFLXN TO MAX STRSS
%u2: SED MAX STRSS TO LAST STRAIN PULLOUT PT
%u3: SED LAST STRAIN PULLOUT PT TO LAST DATA PT

subplot(3,1,1);plot(mm,gm,'k-','LineWidth',.5);
hold on;
subplot(3,1,1);plot(mm,gm,'ko','MarkerSize',5);
hold off

axis([-inf inf -inf inf]);
set(gca,'FontName','times')
set(gca,'FontSize',10) % AXES NUMERICAL LABELS
set(gca,'LineWidth',1.5)
set(gca,'Box','off')
ylabel('Load [grams]','FontSize',10)
xlabel('Displacement [mm]','FontSize',10)


subplot(3,1,2);plot(ez_all,sz_all,'ko','MarkerSize',5);
hold on;
subplot(3,1,2);plot(ez,sz,'k*','MarkerSize',5);
subplot(3,1,2);plot(ezx,psz,'k-','LineWidth',.5)
text(ezs,szs,'\leftarrow MAXGRAD','FontSize',10)
subplot(3,1,2);plot(X,Y,'k--','LineWidth',.5) %HORIZONTAL DASH LINE
%subplot(3,1,2);plot(ezp,szp,'k-','LineWidth',.5) %PULL OUT REGION
%subplot(3,1,2);plot(X0,Y0,'k-','LineWidth',5) %PULL OUT REGION
%text(ez(nmaxm),sz(nmaxm),'\downarrow PO','FontSize',10)
subplot(3,1,2);plot(ez(nmaxm),sz(nmaxm),'r.','MarkerSize',35)
hold off;

axis([-inf inf -inf inf]);
set(gca,'FontName','times')
set(gca,'FontSize',10) % AXES NUMERICAL LABELS
set(gca,'LineWidth',1.5)
set(gca,'Box','off')
ylabel('{\sigma} N/{m^2}','FontSize',10)
xlabel('\epsilon','FontSize',10)

subplot(3,1,3);plot(ezx,dsz,'k-','LineWidth',.5) %PLOT THE GRAD VS EZ

axis([-inf inf -inf inf]);
set(gca,'FontName','times')
set(gca,'FontSize',10) % AXES NUMERICAL LABELS
set(gca,'LineWidth',1.5)
set(gca,'Box','off')
ylabel('derivative of \sigma','FontSize',10)
xlabel('\epsilon','FontSize',10)